﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Problems.DataAnalysis;
using HeuristicLab.Problems.DataAnalysis.Transformations;

namespace HeuristicLab.DataPreprocessing {

  public interface IPreprocessingData : INamedItem {
    T GetCell<T>(int columnIndex, int rowIndex);

    void SetCell<T>(int columnIndex, int rowIndex, T value);

    string GetCellAsString(int columnIndex, int rowIndex);

    [Obsolete("use the index based variant, is faster")]
    IList<T> GetValues<T>(string variableName, bool considerSelection = false);
    IList<T> GetValues<T>(int columnIndex, bool considerSelection = false);

    void SetValues<T>(int columnIndex, IList<T> values);

    void InsertRow(int rowIndex);
    void DeleteRow(int rowIndex);

    void InsertColumn<T>(string variableName, int columnIndex);

    void DeleteColumn(int columnIndex);

    IntRange TrainingPartition { get; }
    IntRange TestPartition { get; }

    IList<ITransformation> Transformations { get; }

    IEnumerable<string> VariableNames { get; }
    string GetVariableName(int columnIndex);
    int GetColumnIndex(string variableName);

    bool IsType<T>(int columnIndex);

    int Columns { get; }
    int Rows { get; }

    Dataset ExportToDataset();

    void SetSelection(IDictionary<int, IList<int>> selection);
    IDictionary<int, IList<int>> GetSelection();
    void ClearSelection();

    event EventHandler SelectionChanged;
  }
}
